@@ -1,19 +1,19 @@
 /*
-* Licensed to the Apache Software Foundation (ASF) under one or more
-* contributor license agreements.  See the NOTICE file distributed with
-* this work for additional information regarding copyright ownership.
-* The ASF licenses this file to You under the Apache License, Version 2.0
-* (the "License"); you may not use this file except in compliance with
-* the License.  You may obtain a copy of the License at
-*
-*     http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*/
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 package compressionFilters;
 
 import java.io.IOException;
@@ -52,12 +52,6 @@ public class CompressionFilter implements Filter {
     // 8KB is what tomcat would use by default anyway
     private static final int MIN_BUFFER = 8192;
 
-    /**
-     * The filter configuration object we are associated with.  If this value
-     * is null, this filter instance is not currently configured.
-     */
-    private FilterConfig config = null;
-
     /**
      * The threshold number to compress.
      */
@@ -86,62 +80,61 @@ public class CompressionFilter implements Filter {
     @Override
     public void init(FilterConfig filterConfig) {
 
-        config = filterConfig;
         if (filterConfig != null) {
             String value = filterConfig.getInitParameter("debug");
             if (value!=null) {
                 debug = Integer.parseInt(value);
-            }
+        }
 
             String str = filterConfig.getInitParameter("compressionThreshold");
-            if (str!=null) {
-                compressionThreshold = Integer.parseInt(str);
-                if (compressionThreshold != 0 && compressionThreshold < MIN_THRESHOLD) {
-                    if (debug > 0) {
-                        System.out.println("compressionThreshold should be either 0 - no compression or >= " + MIN_THRESHOLD);
-                        System.out.println("compressionThreshold set to " + MIN_THRESHOLD);
-                    }
-                    compressionThreshold = MIN_THRESHOLD;
-                }
-            }
-
-            str = filterConfig.getInitParameter("compressionBuffer");
-            if (str!=null) {
-                compressionBuffer = Integer.parseInt(str);
-                if (compressionBuffer < MIN_BUFFER) {
-                    if (debug > 0) {
-                        System.out.println("compressionBuffer should be >= " + MIN_BUFFER);
-                        System.out.println("compressionBuffer set to " + MIN_BUFFER);
-                    }
-                    compressionBuffer = MIN_BUFFER;
-                }
-            }
-
-            str = filterConfig.getInitParameter("compressionMimeTypes");
-            if (str!=null) {
-                List<String> values = new ArrayList<String>();
-                StringTokenizer st = new StringTokenizer(str, ",");
-
-                while (st.hasMoreTokens()) {
-                    String token = st.nextToken().trim();
-                    if (token.length() > 0) {
-                        values.add(token);
-                    }
-                }
-
-                if (values.size() > 0) {
-                    compressionMimeTypes = values.toArray(new String[0]);
-                } else {
-                    compressionMimeTypes = null;
-                }
-
+        if (str != null) {
+            compressionThreshold = Integer.parseInt(str);
+            if (compressionThreshold != 0 && compressionThreshold < MIN_THRESHOLD) {
                 if (debug > 0) {
-                    System.out.println("compressionMimeTypes set to " +
-                            Arrays.toString(compressionMimeTypes));
+                    System.out.println("compressionThreshold should be either 0 - no compression or >= " + MIN_THRESHOLD);
+                    System.out.println("compressionThreshold set to " + MIN_THRESHOLD);
                 }
+                compressionThreshold = MIN_THRESHOLD;
             }
         }
 
+            str = filterConfig.getInitParameter("compressionBuffer");
+        if (str != null) {
+            compressionBuffer = Integer.parseInt(str);
+            if (compressionBuffer < MIN_BUFFER) {
+                if (debug > 0) {
+                    System.out.println("compressionBuffer should be >= " + MIN_BUFFER);
+                    System.out.println("compressionBuffer set to " + MIN_BUFFER);
+                }
+                compressionBuffer = MIN_BUFFER;
+            }
+        }
+
+            str = filterConfig.getInitParameter("compressionMimeTypes");
+        if (str != null) {
+            List<String> values = new ArrayList<>();
+            StringTokenizer st = new StringTokenizer(str, ",");
+
+            while (st.hasMoreTokens()) {
+                String token = st.nextToken().trim();
+                if (token.length() > 0) {
+                    values.add(token);
+                }
+            }
+
+            if (values.size() > 0) {
+                compressionMimeTypes = values.toArray(new String[0]);
+            } else {
+                compressionMimeTypes = null;
+            }
+
+            if (debug > 0) {
+                System.out.println("compressionMimeTypes set to " +
+                        Arrays.toString(compressionMimeTypes));
+            }
+        }
+    }
+
     }
 
     /**
@@ -149,9 +142,6 @@ public class CompressionFilter implements Filter {
     */
     @Override
     public void destroy() {
-
-        this.config = null;
-
     }
 
     /**
@@ -171,8 +161,8 @@ public class CompressionFilter implements Filter {
      * (<code>chain.doFilter()</code>), <br>
      **/
     @Override
-    public void doFilter ( ServletRequest request, ServletResponse response,
-                        FilterChain chain ) throws IOException, ServletException {
+    public void doFilter (ServletRequest request, ServletResponse response, FilterChain chain )
+            throws IOException, ServletException {
 
         if (debug > 0) {
             System.out.println("@doFilter");
@@ -245,24 +235,5 @@ public class CompressionFilter implements Filter {
             return;
         }
     }
-
-    /**
-     * Set filter config
-     * This function is equivalent to init. Required by Weblogic 6.1
-     *
-     * @param filterConfig The filter configuration object
-     */
-    public void setFilterConfig(FilterConfig filterConfig) {
-        init(filterConfig);
-    }
-
-    /**
-     * Required by Weblogic 6.1
-     *
-     * @return the FilterConfig that was used to initialise this filter.
-     */
-    public FilterConfig getFilterConfig() {
-        return config;
-    }
 }
 
